[![CI](https://github.com/vintasoftware/django-ai-assistant/actions/workflows/ci.yml/badge.svg)](https://github.com/vintasoftware/django-ai-assistant/actions/workflows/ci.yml)
[![Coverage Status](https://coveralls.io/repos/github/vintasoftware/django-ai-assistant/badge.svg?branch=main)](https://coveralls.io/github/vintasoftware/django-ai-assistant?branch=main)
[![Discord Server](https://img.shields.io/discord/1260577482122203206)](https://discord.gg/mqdubnPb)

# django-ai-assistant

<img align="left" src="https://raw.githubusercontent.com/vintasoftware/django-ai-assistant/main/docs/images/favicon.svg" height="120" alt="robot logo">

Combine the power of LLMs with Django's productivity to build intelligent applications.
Let AI Assistants call methods from Django's side and do anything your users need!

Use AI Tool Calling and RAG with Django to easily build state of the art AI Assistants.

Please check the documentation: [https://vintasoftware.github.io/django-ai-assistant/](https://vintasoftware.github.io/django-ai-assistant/)

## 5 minute demo

https://github.com/vintasoftware/django-ai-assistant/assets/397989/715d7608-e657-4dce-a7be-2909679f814b

## Community

Feel free to ask questions and share your work on our [Discord Server](https://discord.gg/fQfH9PkJM6)!

## Contributing

You're welcome to contribute with Django AI Assistant! Please feel free to tackle existing [issues](https://github.com/vintasoftware/django-ai-assistant/issues). If you have a new idea, please create a thread on [Discussions](https://github.com/vintasoftware/django-ai-assistant/discussions). 

Check our [contributing guide](CONTRIBUTING.md) to learn more about how to develop and test the project locally, before opening a pull request.

## Commercial Support

[![alt text](https://avatars2.githubusercontent.com/u/5529080?s=80&v=4 "Vinta Logo")](https://www.vintasoftware.com/)

This is an open-source project maintained by [Vinta Software](https://www.vinta.com.br/). We are always looking for exciting work! If you need any commercial support, feel free to get in touch: contact@vinta.com.br
